Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(631)

Unified Diff: content/common/content_security_policy/csp_context.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/child/db_message_filter.cc ('k') | content/common/cross_site_document_classifier.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/content_security_policy/csp_context.cc
diff --git a/content/common/content_security_policy/csp_context.cc b/content/common/content_security_policy/csp_context.cc
index 4fd6b8a24e1befe71d148aeec473f16a65a4b776..b2d4164248b3d12cf41cf4219ecab31c718aa68e 100644
--- a/content/common/content_security_policy/csp_context.cc
+++ b/content/common/content_security_policy/csp_context.cc
@@ -70,9 +70,9 @@ bool CSPContext::ShouldModifyRequestUrlForCsp(
void CSPContext::SetSelf(const url::Origin origin) {
self_source_.reset();
// When the origin is unique, no URL should match with 'self'. That's why
// |self_source_| stays undefined here.
- if (origin.unique())
+ if (origin.opaque())
return;
if (origin.scheme() == url::kFileScheme) {
« no previous file with comments | « content/child/db_message_filter.cc ('k') | content/common/cross_site_document_classifier.cc » ('j') | no next file with comments »
@@ -70,9 +70,9 @@ bool CSPContext::ShouldModifyRequestUrlForCsp(
void CSPContext::SetSelf(const url::Origin origin) {
self_source_.reset();
- // When the origin is unique, no URL should match with 'self'. That's why
+ // When the origin is opaque, no URL should match with 'self'. That's why
// |self_source_| stays undefined here.

Powered by Google App Engine
This is Rietveld 408576698